@@ -116,7 +116,7 @@ class PccEmulator(object):
         # bw = self.trace_list[0][1]
 
         queue = int(random.uniform(*self.queue_range))
-        self.links = [Link(self.trace_list, queue) , Link([], queue)]
+        self.links = [Link(self.trace_list, queue) , Link([], queue, delay=self.trace_list[0][3])]
         #self.senders = [Sender(0.3 * bw, [self.links[0], self.links[1]], 0, self.history_len)]
         #self.senders = [Sender(random.uniform(0.2, 0.7) * bw, [self.links[0], self.links[1]], 0, self.history_len)]
         solution = Aitrans_solution() if not self.solution else self.solution
